@@ -33,12 +33,16 @@ class LinuxNativeMultipathBlockDevice(LinuxBlockDeviceMixin, multipath.Multipath
 
     @cached_method
     def get_display_name(self):
-        return self.sysfs_device.block_device_name
+        return self.multipath_object.dm_name
 
     @cached_method
     def get_block_access_path(self):
         return "/dev/mapper/{}".format(self.multipath_object.device_name)
 
+    @cached_method
+    def get_device_mapper_access_path(self):
+        return "/dev/{}".format(self.multipath_object.dm_name)
+
     @cached_method
     def get_paths(self):
         paths = list()
